"""
    Nomad Broker

    Make payments, and customs declaration for orders.  # noqa: E501

    The version of the OpenAPI document: 1.2.1
    Contact: manwei@samarkand.global
    Generated by: https://openapi-generator.tech
"""


import unittest

import nomad_broker_cli
from nomad_broker_cli.api.youzan_api import YouzanApi  # noqa: E501


class TestYouzanApi(unittest.TestCase):
    """YouzanApi unit test stubs"""

    def setUp(self):
        self.api = YouzanApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_declare_order_youzan_post(self):
        """Test case for declare_order_youzan_post

        """
        pass

    def test_query_order_youzan_post(self):
        """Test case for query_order_youzan_post

        """
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from nomad_broker_cli.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from nomad_broker_cli.model.api_response import ApiResponse
from nomad_broker_cli.model.customs_request import CustomsRequest
from nomad_broker_cli.model.customs_request_sub_order import CustomsRequestSubOrder
from nomad_broker_cli.model.customs_response import CustomsResponse
from nomad_broker_cli.model.declare_order_youzan_req_body import DeclareOrderYouzanReqBody
from nomad_broker_cli.model.declare_order_youzan_res200 import DeclareOrderYouzanRes200
from nomad_broker_cli.model.error_api_response import ErrorApiResponse
from nomad_broker_cli.model.inline_object import InlineObject
from nomad_broker_cli.model.inline_response200 import InlineResponse200
from nomad_broker_cli.model.inline_response401 import InlineResponse401
from nomad_broker_cli.model.inline_response422 import InlineResponse422
from nomad_broker_cli.model.inline_response500 import InlineResponse500
from nomad_broker_cli.model.pay_product import PayProduct
from nomad_broker_cli.model.payment_close_response import PaymentCloseResponse
from nomad_broker_cli.model.payment_detail_response import PaymentDetailResponse
from nomad_broker_cli.model.payment_invocation_request import PaymentInvocationRequest
from nomad_broker_cli.model.payment_method import PaymentMethod
from nomad_broker_cli.model.payment_request import PaymentRequest
from nomad_broker_cli.model.payment_response import PaymentResponse
from nomad_broker_cli.model.payment_type import PaymentType
from nomad_broker_cli.model.query_order_youzan_req_body import QueryOrderYouzanReqBody
from nomad_broker_cli.model.query_order_youzan_res200 import QueryOrderYouzanRes200
